@@ -12,14 +12,15 @@ from PIL import Image
 import re
 
 def sumdumbfun(x,y): # this is only here to test the package during development
-    return x*y*y
+    return x*y*y*y
 
 ## RootDir establishes the export and data folder structure
 def RootDir(corename, Formation_names):
     Root_path = os.path.dirname(os.getcwd())
     
     main_dir = ['CoreData','CoreOutput']    # make it so CorePyCodes is version controlled
-    CoreData_dir= ['CoreAttributes', 'CoreXRF','CoreBoxPhotos', 'CoreTubes','CoreNeuralModel','CoreBeta']   
+    CoreData_dir= ['CoreAttributes', 'CoreXRF','CoreBoxPhotos', 'CoreTubes','CoreNeuralModel','CoreBeta','WirelineLogs']
+    CoreOutput_dir= ['CrossSection']  
         
     for i in range(0, len(main_dir)):
         dirName =  str(Root_path + '/' + str(main_dir[i]))
@@ -33,6 +34,18 @@ def RootDir(corename, Formation_names):
         dirName =  str(Root_path + '/' + main_dir[0]) + '/' + str(CoreData_dir[i])
         if not os.path.exists(dirName):
 		        os.makedirs(dirName)
+                
+    for i in range(0, len(CoreOutput_dir)):
+
+        dirName =  str(Root_path + '/' + main_dir[1]) + '/' + str(CoreOutput_dir[i])
+        if not os.path.exists(dirName):
+		        os.makedirs(dirName)
+                
+    for i in range(0, len(CoreOutput_dir)):
+
+        dirName =  str(Root_path + '/' + main_dir[1]) + '/' + str(CoreOutput_dir[i]) + '/' + str(Formation_names)
+        if not os.path.exists(dirName):
+		        os.makedirs(dirName)
  
     for i in range(0, len(corename)):
         dirName =  str(Root_path + '/' + main_dir[1]) + '/' + str(corename)
